@@ -7,15 +7,19 @@ __all__ = [
     "denorm",
     "norm",
 ]
-__version__ = "0.4.0"
+__version__ = "0.5.2"
 
 from .common.noise import gaussian, gaussian_like, uniform_int, pad
 from .common.vis import make_history
 from .common.norm import denorm, norm
 
-from . import data
-
-from .lit_modules import *
-
+from . import lit_modules
 from . import diffusion_models
 from . import equations
+from . import models
+
+from . import data_modules
+from . import datasets
+
+from .lit_modules import *
+from .data_modules import *
