@@ -5,6 +5,12 @@ from torchvision.utils import make_grid
 
 
 def make_history(history):
+    r"""Visualize diffusion process given an array of histories
+
+    Args:
+        history (List[torch.Tensor]): list of diffusion history with each item as a tensor of shape :math:`(N, C, H, W)`
+
+    """
     if len(history) == 1:
         img = history[-1]
 
